spacepy.toolbox.eventTimer — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.eventTimer

`spacepy.toolbox.` `eventTimer`(Event, Time1)

  Times an event then prints out the time and the name of the event, nice for debugging and seeing that the code is progressing

  Parameters: | Event : str Name of the event, string is printed out by function Time1 : time.time the time to difference in the function
  Returns: | Time2 : time.time the new time for the next call to EventTimer

  Examples

      >>> import spacepy.toolbox as tb
      >>> import time
      >>> t1 = time.time()
      >>> t1 = tb.eventTimer('Test event finished', t1)
      ('4.40', 'Test event finished')

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »